# amber99sb.xml
Forcefield obtained from [Openmm](https://github.com/openmm/openmm/blob/master/wrappers/python/openmm/app/data/amber99sb.xml)

# amber99sb-ucb.xml
Modified version of `amber99sb.xml` according to [this instructions](https://github.com/strodel-group/AMBER99SB-UCB).

# RNA.OL3.xml
RNA forcefield obtained from [Openmm](https://github.com/openmm/openmm/blob/master/wrappers/python/openmm/app/data/amber14/RNA.OL3.xml)
